// This file is part of Substrate.

// Copyright (C) Parity Technologies (UK) Ltd.
// SPDX-License-Identifier: Apache-2.0

// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//! Expose the auto generated weight files.

pub mod block_weights;
pub mod cumulus_pallet_xcmp_queue;
pub mod extrinsic_weights;
pub mod frame_system;
pub mod pallet_balances;
pub mod pallet_bridge_grandpa_rococo_finality;
pub mod pallet_bridge_grandpa_westend_finality;
pub mod pallet_bridge_grandpa_wococo_finality;
pub mod pallet_bridge_messages_rococo_to_westend;
pub mod pallet_bridge_messages_rococo_to_wococo;
pub mod pallet_bridge_messages_wococo_to_rococo;
pub mod pallet_bridge_parachains_within_rococo;
pub mod pallet_bridge_parachains_within_westend;
pub mod pallet_bridge_parachains_within_wococo;
pub mod pallet_bridge_relayers;
pub mod pallet_collator_selection;
pub mod pallet_multisig;
pub mod pallet_session;
pub mod pallet_timestamp;
pub mod pallet_utility;
pub mod pallet_xcm;
pub mod paritydb_weights;
pub mod rocksdb_weights;
pub mod xcm;

pub use block_weights::constants::BlockExecutionWeight;
pub use extrinsic_weights::constants::ExtrinsicBaseWeight;
pub use paritydb_weights::constants::ParityDbWeight;
pub use rocksdb_weights::constants::RocksDbWeight;

use crate::Runtime;
use frame_support::weights::Weight;

// import trait from dependency module
use ::pallet_bridge_relayers::WeightInfoExt as _;

impl pallet_bridge_messages::WeightInfoExt
	for pallet_bridge_messages_wococo_to_rococo::WeightInfo<crate::Runtime>
{
	fn expected_extra_storage_proof_size() -> u32 {
		bp_bridge_hub_rococo::EXTRA_STORAGE_PROOF_SIZE
	}

	fn receive_messages_proof_overhead_from_runtime() -> Weight {
		pallet_bridge_relayers::WeightInfo::<Runtime>::receive_messages_proof_overhead_from_runtime(
		)
	}

	fn receive_messages_delivery_proof_overhead_from_runtime() -> Weight {
		pallet_bridge_relayers::WeightInfo::<Runtime>::receive_messages_delivery_proof_overhead_from_runtime()
	}
}

impl pallet_bridge_messages::WeightInfoExt
	for pallet_bridge_messages_rococo_to_wococo::WeightInfo<crate::Runtime>
{
	fn expected_extra_storage_proof_size() -> u32 {
		bp_bridge_hub_wococo::EXTRA_STORAGE_PROOF_SIZE
	}

	fn receive_messages_proof_overhead_from_runtime() -> Weight {
		pallet_bridge_relayers::WeightInfo::<Runtime>::receive_messages_proof_overhead_from_runtime(
		)
	}

	fn receive_messages_delivery_proof_overhead_from_runtime() -> Weight {
		pallet_bridge_relayers::WeightInfo::<Runtime>::receive_messages_delivery_proof_overhead_from_runtime()
	}
}

impl pallet_bridge_messages::WeightInfoExt
	for pallet_bridge_messages_rococo_to_westend::WeightInfo<crate::Runtime>
{
	fn expected_extra_storage_proof_size() -> u32 {
		bp_bridge_hub_westend::EXTRA_STORAGE_PROOF_SIZE
	}

	fn receive_messages_proof_overhead_from_runtime() -> Weight {
		pallet_bridge_relayers::WeightInfo::<Runtime>::receive_messages_proof_overhead_from_runtime(
		)
	}

	fn receive_messages_delivery_proof_overhead_from_runtime() -> Weight {
		pallet_bridge_relayers::WeightInfo::<Runtime>::receive_messages_delivery_proof_overhead_from_runtime()
	}
}

impl pallet_bridge_parachains::WeightInfoExt
	for pallet_bridge_parachains_within_rococo::WeightInfo<crate::Runtime>
{
	fn expected_extra_storage_proof_size() -> u32 {
		bp_bridge_hub_rococo::EXTRA_STORAGE_PROOF_SIZE
	}
}

impl pallet_bridge_parachains::WeightInfoExt
	for pallet_bridge_parachains_within_westend::WeightInfo<crate::Runtime>
{
	fn expected_extra_storage_proof_size() -> u32 {
		bp_bridge_hub_westend::EXTRA_STORAGE_PROOF_SIZE
	}
}

impl pallet_bridge_parachains::WeightInfoExt
	for pallet_bridge_parachains_within_wococo::WeightInfo<crate::Runtime>
{
	fn expected_extra_storage_proof_size() -> u32 {
		bp_bridge_hub_wococo::EXTRA_STORAGE_PROOF_SIZE
	}
}
